@@ -27,7 +27,7 @@ __all__ = ("CommandExecutedWaiter",)
 
 class CommandExecutedWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/ssm.html#SSM.Waiter.CommandExecuted)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ssm.html#SSM.Waiter.CommandExecuted)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/waiters.html#commandexecutedwaiter)
     """
 
@@ -36,10 +36,10 @@ class CommandExecutedWaiter(Boto3Waiter):
         *,
         CommandId: str,
         InstanceId: str,
-        PluginName: str = None,
-        WaiterConfig: WaiterConfigTypeDef = None
+        PluginName: str = ...,
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/ssm.html#SSM.Waiter.CommandExecuted.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/ssm.html#SSM.Waiter.CommandExecuted.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/waiters.html#commandexecutedwaiter)
         """
